import { APIClient } from "./ApiClient";
import { VMGroup } from "./ServerApi";
import { VMInfo, VMState } from "./VMApi";

export interface GroupVMState {
  [key: string]: VMState;
}

export interface TreatmentResult {
  ok: number;
  failed: number;
}

export class GroupApi {
  /**
   * Get the state of the VMs of a group
   */
  static async State(g: VMGroup): Promise<GroupVMState> {
    return (
      await APIClient.exec({ method: "GET", uri: `/group/${g.id}/vm/state` })
    ).data;
  }

  /**
   * Request to start the VM of a group
   */
  static async StartVM(g: VMGroup, vm?: VMInfo): Promise<TreatmentResult> {
    return (
      await APIClient.exec({
        method: "GET",
        uri: `/group/${g.id}/vm/start` + (vm ? `?vm_id=${vm.uuid}` : ""),
      })
    ).data;
  }
}
